==> hboard-1.0.3.tar.gz: hboard/list.php <==
<?php

/* EtchiBoard Version 1.0
     list.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

include ("lib/admin.inc"); //  ȯ漳 include
include ("lib/headfoot.inc"); //  /ϴܺ 
include ("lib/list.inc"); //   function
include ("lib/message.inc"); // ޽ function

PrintHeader(); //  , ...

#   ϱ (Ѱ  )

 if(!$_SERVER["REQUEST_URI"]) $page_this = $_SERVER["PHP_SELF"] ."?" .$_SERVER["QUERY_STRING"];
 else $page_this = $_SERVER["REQUEST_URI"];

 $page_this = str_replace("&", "_and_", $page_this);

# ̹   뷮 о
  $file_open = file("db/img/dbinfo");
  $db_size = trim($file_open[1]);

 if($db_size <= 1048576) {
  $db_size = (float)($db_size/1024);
  $db_size = sprintf("%01.2f", $db_size) ." KB";
 }
 else if($db_size >= 1048577) {
  $db_size = (float)($db_size/1024/1024);
  $db_size = sprintf("%01.2f", $db_size) ." MB";
 }

# DB 
$dbconnect = mysql_connect($hostname, $username, $dbpass);
 mysql_select_db($dbname);

// ü Խù  ϱ
$result = mysql_fetch_array(mysql_query("select count(*) from hboard_db_article", $dbconnect));
$fileidx = $result[0];

//  Խù ϱ
$result = mysql_fetch_array(mysql_query("select count(*) from hboard_db_article where deleted='t'", $dbconnect));
$deleted_fileidx = $result[0];

mysql_close($dbconnect);

  ##  Ȯ κ
  if(!$page) $page = 1; // Է¹ ʾ, ڵ 1 ϱ

  # о ε ̿  ѱ
   $startpage = sprintf("%d", $fileidx/$admin_data[app]+0.99); //   -_-
   if($startpage < 1) $startpage = 1;

    $footart = $fileidx-($admin_data[app]*$page); //   ϴ Խù
    $headart = $footart + $admin_data[app]; //   ֻ Խù

if($page < 0) PrintMessage("   ʰ߽ϴ.", "error");
else if($page > $startpage) PrintMessage("   ʰ߽ϴ.", "error");
else {
?>

<script language="JavaScript" type="">

function Preview(Change_form,i){
        var strPath;
        d_pic = "d_pic1";
        document.all(d_pic).innerHTML="<IMG alt='Preview' border=0 name=pic1 src='" + eval("Change_form.picture.value") + "' style='visibility:hidden'>";
        stretch_i="stretchimage('320','240','1')";
        window.setTimeout(stretch_i,1000);
}

function stretchimage(iw,ih,j){
	iWidth=parseInt(eval("document.pic"+j+".width"));
	iHeight=parseInt(eval("document.pic"+j+".height"));
	if(iWidth>parseInt(iw) && iWidth>=iHeight){
		eval('document.pic'+j+'.height=parseInt(iw)/iWidth*iHeight;');
		eval('document.pic'+j+'.width=parseInt(iw);');
	}
	else if(iHeight>parseInt(ih) && iHeight>iWidth){
		eval('document.pic'+j+'.width=parseInt(ih)/iHeight*iWidth;');
		eval('document.pic'+j+'.height=parseInt(ih);');
	}

	eval('document.pic'+j+'.style.visibility="visible";');
}

function checkvalue() {
		if(document.inputform.name.value == ""){
			alert("ۼ ̸  ּ.");
			document.inputform.name.focus();
			return true;
		}
		else if(document.inputform.picture.value == ""){
			alert("ε ׸ ϼ.");
			document.inputform.picture.focus();
			return true;
		}
		else if(document.inputform.passwd.value == ""){
			alert("йȣ Է ּ.");
			document.inputform.passwd.focus();
			return true;
		}
		else if(document.inputform.ne.value == ""){
			alert("Խù ̳   Է ּ.");
			document.inputform.ne.focus();
			return true;
		}
		else{
			document.inputform.submit();
		}
}


function checksearch() {
		if
		(document.searchform.search_word.value == ""){
			alert("˻ Է ּ.");
			document.searchform.search_word.focus();
			return true;
		}
		else {
			document.searchform.submit();
		}
}

function Openwindow(name, url, left, top, width, height, toolbar, menubar, statusbar, scrollbar, resizable)
// script from Namo Webeditor
{
  toolbar_str = toolbar ? 'yes' : 'no';
  menubar_str = menubar ? 'yes' : 'no';
  statusbar_str = statusbar ? 'yes' : 'no';
  scrollbar_str = scrollbar ? 'yes' : 'no';
  resizable_str = resizable ? 'yes' : 'no';
  window.open(url, name, 'left='+left+',top='+top+',width='+width+',height='+height+',toolbar='+toolbar_str+',menubar='+menubar_str+',status='+statusbar_str+',scrollbars='+scrollbar_str+',resizable='+resizable_str);
}
</script>

<!-- ۾ κ  -->

<table align="center" cellpadding="0" cellspacing="0" width="640">
<tr><td width="974" height="20" background="skin/<?php echo $admin_data[skin]?>/title_bg.gif">
<table cellpadding="0" cellspacing="0" width="100%">
<tr><td width="17" height="25" background="skin/<?php echo $admin_data[skin]?>/title_bg.gif">
<p align="center">
<img src="skin/<?php echo $admin_data[skin]?>/write.gif" width="14" height="20" border="0" alt="write.gif">
</p></td><td width="674" height="20" background="skin/<?php echo $admin_data[skin]?>/title_bg.gif">
<p><font color="<?php echo $skin[sfont2_color]?>">&nbsp;<b> Խù ۼ..</b></font></p>
</td></tr>
</table>
</td></tr>

<tr><td>
<form name="inputform" method="post" action="./post_article.php" enctype="multipart/form-data" onsubmit="this.submit_btn.disabled=true">

<TABLE border=1 width=640 cellspacing=0 cellpadding=7 bgcolor="<?php echo $skin[image_table_bgcolor]?>"><TR ALIGN=CENTER><TD>
<table border=0 cellpadding=0 cellspacing=0><tr><td>
<TABLE BORDER=0 CELLPADDING=0 CELLSPACING=0>
<TR><TD WIDTH=50>Name</TD>
<TD><INPUT TYPE=text NAME="name" SIZE=20 MAXLENGTH=30 VALUE="<?php echo $HTTP_COOKIE_VARS["hboard10_name"]?>"></TD></TR>

<TR><TD>Mail</TD><TD>
<INPUT TYPE=text NAME="email" SIZE=32 MAXLENGTH=100 VALUE="<?php echo $HTTP_COOKIE_VARS["hboard10_email"]?>"></TD></TR>

<TR><TD>URL(*)</TD><TD>
<INPUT TYPE=text NAME="homepage" SIZE=32 MAXLENGTH=255 VALUE="
<?php
if($HTTP_COOKIE_VARS["hboard10_homepage"] == "") echo "http://";
else echo $HTTP_COOKIE_VARS["hboard10_homepage"];
?>">
</TD></TR>

<TR><TD>File</TD><TD>
<INPUT TYPE=file NAME="picture" SIZE=20 MAXLENGTH=255 onChange='Preview(this.form,1);'>
<span style="font-size:8pt;">
<?php
if($admin_data[fileup_max] != "0") {
 //  ε   : KB, MB  ȯؼ Ѹ

 if($admin_data[fileup_max] <= 1023999) $fileup_max = (int)($admin_data[fileup_max]/1024+0.5) ."KB";
 else $fileup_max = sprintf("%0.2f", $admin_data[fileup_max]/1024/1024) ."MB";
 echo "(" .$fileup_max ." <font color=\"red\">MAX</font>)";
}
else {
echo "<font color=\"red\">(Unlimited)</font>";
}
?>

</span>
</TD></TR>

<TR><TD>Password</TD><TD>
<INPUT TYPE=password NAME="passwd" SIZE=9 MAXLENGTH=30></TD></TR>

<TR><TD WIDTH=50>Title</TD><TD>
 <input type=text name="title" size=32 maxlength=255 value=""></TD></TR>
</TABLE>

<TABLE BORDER=0 CELLPADDING=0 CELLSPACING=0>
<TR><TD><TEXTAREA NAME="ne" ROWS=7 COLS=45></TEXTAREA></TD></TR>
</TABLE>

<TABLE BORDER=0 CELLPADDING=0 CELLSPACING=0 WIDTH="100%">
<TR><TD ALIGN=CENTER>
<INPUT name="submit_btn" type=button value="Submit" onclick="checkvalue();" accesskey=s>&nbsp;<INPUT name="reset_btn" TYPE=reset VALUE="Reset">
</TD></TR>
</TABLE>
</form>
</td></tr>
</table>

<TD WIDTH=320 HEIGHT=240>
<DIV id='d_pic1' style='width:320px;height:240px;overflow:hidden;' align='center'>
<IMG border='0' name='pic1' SRC='skin/<?php echo $admin_data[skin]?>/preview.jpg' WIDTH='320' HEIGHT='240' alt='Preview'>
</DIV>

</TD></tr>
</table>
</td></tr>
</table>
<!-- ۾ κ  -->
<center>
<br>
<table align="center" width="90%" cellpadding="0" cellspacing="0" bgcolor="<?php echo $skin[image_table_bgcolor]?>">
<tr><td width="37">
<p align="center"><span style="font-size:9pt;">
<img src="skin/<?php echo $admin_data[skin]?>/info.jpg" width="32" height="32" alt="Info"></span></p>
</td>
<td>
<p><span style="font-size:9pt;"> <?php echo ($fileidx - $deleted_fileidx)?> Խù ϵǾ ֽϴ. ( Խù <?php echo $deleted_fileidx?>)<br> <?php echo $page?>  / ü&nbsp;<?php echo $startpage?>&nbsp; ( <?php echo $admin_data[app]?> , ̹ DB: <?php echo $db_size?>)</span></p>
</td>

<td width="37">
<p><span style="font-size:9pt;"><a href="#search"><img src="skin/<?php echo $admin_data[skin]?>/search.jpg" width="32" height="32" alt="˻" border="0"></a></span></p>
</td>

<?php
/**********  α  óκ **********/

 if($HTTP_COOKIE_VARS["hboard_admin_login"] == $admin_data[passwd]) {
?>

<td width="37">
<p><span style="font-size:9pt;"><a href="javascript:Openwindow('hb_config', 'config.php?from=<?php echo $page_this?>', 30, 30, 700, 610, 0, 0, 0, 1, 0)"><img src="skin/<?php echo $admin_data[skin]?>/config.jpg" width="32" height="32" alt="Խ ȯ " border="0"></a></span></p>
</td>
<td width="37">
<p><span style="font-size:9pt;"><a href="javascript:Openwindow('hb_iconman', 'iconman.php', 60, 60, 610, 400, 0, 0, 0, 1, 1)"><img src="skin/<?php echo $admin_data[skin]?>/addicon.jpg" width="32" height="32" alt=" " border="0"></a></span></p>
</td>
<td width="37">
<p><span style="font-size:9pt;"><a href="admin_logout.php?from=<?php echo $page_this?>"><img src="skin/<?php echo $admin_data[skin]?>/logout.jpg" width="32" height="32" alt=" α׾ƿ" border="0"></a></span></p>
</td>

<?php
 }
 else {
?>

<td width="37">
<p><span style="font-size:9pt;"><a href="javascript:Openwindow('hb_login', 'admin.php?from=<?php echo $page_this?>', 50, 50, 360, 140, 0, 0, 0, 0, 0)"><img src="skin/<?php echo $admin_data[skin]?>/login.jpg" width="32" height="32" alt=" α" border="0"></a></span></p>
</td>

<?php
 }
/**********  α  óκ  **********/
?>
</tr></table>
<br>
<!-- ºκ  -->
<?php

 if($fileidx<=0) {
  echo "<br><font size=5>Ͱ ϴ!</font><br><font size=3> Է Խù ۼϿ ֽʽÿ.</font><br><br><hr color=\"${skin[hr_color]}\" width=\"90%\"><br>\n";
  }
 else {
  // PrintArticle  : PrintArticle(,,true/false) .. -.-
	PrintArticle($headart, ($footart+1), true);
 }

echo " <b><font color=blue>" .$page ."</font></b>  <font color=green>/</font> ü <b><font color=red>" .$startpage ."</font></b> <br>";

if($page>1) {
echo "<a href=\"list.php?page=1\" title=\"ù \">|</a>&nbsp;<a href=\"list.php?page=" .($page-1) ."\" title=\" \"></a>&nbsp;&nbsp;";
}
else {
echo "<font color=\"${image_table_bgcolor}\"><a title=\"ù \">|</a>&nbsp;<a title=\" \"></a></font>&nbsp;&nbsp;";
} //   ù  ư

// ģ for κ 
for($pagecnt=($page-4);; $pagecnt++) {
 if($pagecnt<=0) { } //  ó̸ do nothing;
 else if($pagecnt>=$page) {
	 break; } //   
 else {
	 echo "<a href=\"list.php?page=" .$pagecnt ."\">[" .$pagecnt ."]</a>&nbsp;"; }
}

echo "[<b>" .$page ."</b>]&nbsp;";

for($pagecnt=($page+1);; $pagecnt++) {

 if($page<=4) { // ù ?
  if($pagecnt>$startpage) { break; } //   
  else if($pagecnt>=(($page+10)-$page)) { break; }
  else { echo "<a href=\"list.php?page=" .$pagecnt ."\">[" .$pagecnt ."]</a>&nbsp;"; }
 }

 else { // ƴ  Ѥ..
  if($pagecnt>$startpage) { break; } //   
  else if($pagecnt>=($page+5)) { break; } // +5  
  else { echo "<a href=\"list.php?page=" .$pagecnt ."\">[" .$pagecnt ."]</a>&nbsp;"; }
 }
}

// ģ for κ 

if(($footart+1)<=1) {
echo "&nbsp;<font color=\"${image_table_bgcolor}\"><a title=\" \"></a>&nbsp;<a title=\" \">|</a></font>";
}

else {
echo "&nbsp;<a href=\"list.php?page=" .($page+1) ."\" title=\" \"></a>&nbsp;<a href=\"list.php?page=" .$startpage ."\" title=\" \">|</a>";
} //     ư..Ѥ

?>
<span style="font-size:6pt;"><br><br></span>
<a name="search"></a>
<form name="searchform" action="search.php">
<table width="314" align="center" cellpadding="0" cellspacing="0" bgcolor="<?php echo $skin[image_table_bgcolor]?>">
    <tr>
        <td width="18" height="37">
                <p align="center">
		<span style="font-size:9pt;">&nbsp;</span></p>
        </td>
        <td width="56" height="37">
                <p align="center">
                <span style="font-size:9pt;"><img src="skin/<?php echo $admin_data[skin]?>/search.jpg" width="32" height="32" alt="˻" border="0"></span></p>
        </td>
        <td width="79" height="37">
                 <p align="center"><span style="font-size:9pt;">
				<select name="search_type" size="1">
                <option value="name">ۼ</option>
                <option value="subject"> </option>
                <option value="ment"> </option>
                <option value="cfile"> ̸</option>
                </select></span></p>
        </td>
        <td width="120" height="37">
            <p align="center"><span style="font-size:9pt;"><input type="text" name="search_word" maxlength="50" size="15"></span></p>
        </td>
        <td width="50" height="37">
            
                <p align="left">&nbsp;<span style="font-size:9pt;"><input type="button" name="search_go" value="˻" onclick="checksearch();"></span>
        </td>
        <td width="15" height="37">
                <p><span style="font-size:9pt;">&nbsp;</span></p>

        </td>
    </tr>
</table>
</form>

</center>

<!-- ºκ  -->

<?php
}
PrintFooter();
?>

==> hboard-1.0.4.tar.gz: hboard/list.php <==
<?php

/* EtchiBoard Version 1.0
     list.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

include ("lib/admin.inc"); //  ȯ漳 include
include ("lib/headfoot.inc"); //  /ϴܺ 
include ("lib/list.inc"); //   function
include ("lib/message.inc"); // ޽ function

PrintHeader(); //  , ...

#   ϱ (Ѱ  )

 if(!$_SERVER["REQUEST_URI"]) $page_this = $_SERVER["PHP_SELF"] ."?" .$_SERVER["QUERY_STRING"];
 else $page_this = $_SERVER["REQUEST_URI"];

 $page_this = str_replace("&", "_and_", $page_this);

# ̹   뷮 о
  $file_open = file("db/img/dbinfo");
  $db_size = trim($file_open[1]);

 if($db_size <= 1048576) {
  $db_size = (float)($db_size/1024);
  $db_size = sprintf("%01.2f", $db_size) ." KB";
 }
 else if($db_size >= 1048577) {
  $db_size = (float)($db_size/1024/1024);
  $db_size = sprintf("%01.2f", $db_size) ." MB";
 }

# DB 
$dbconnect = mysql_connect($hostname, $username, $dbpass);
 mysql_select_db($dbname);

// ü Խù  ϱ
$result = mysql_fetch_array(mysql_query("select count(*) from hboard_db_article", $dbconnect));
$fileidx = $result[0];

//  Խù ϱ
$result = mysql_fetch_array(mysql_query("select count(*) from hboard_db_article where deleted='t'", $dbconnect));
$deleted_fileidx = $result[0];

mysql_close($dbconnect);

  ##  Ȯ κ
  if(!$page) $page = 1; // Է¹ ʾ, ڵ 1 ϱ

  # о ε ̿  ѱ
   $startpage = sprintf("%d", $fileidx/$admin_data[app]+0.99); //   -_-
   if($startpage < 1) $startpage = 1;

    $footart = $fileidx-($admin_data[app]*$page); //   ϴ Խù
    $headart = $footart + $admin_data[app]; //   ֻ Խù

if($page < 0) PrintMessage("   ʰ߽ϴ.", "error");
else if($page > $startpage) PrintMessage("   ʰ߽ϴ.", "error");
else {
?>

<script language="JavaScript" type="">

function Preview(Change_form,i){
        var strPath;
        d_pic = "d_pic1";
        document.all(d_pic).innerHTML="<IMG alt='Preview' border=0 name=pic1 src='" + eval("Change_form.picture.value") + "' style='visibility:hidden'>";
        stretch_i="stretchimage('320','240','1')";
        window.setTimeout(stretch_i,1000);
}

function stretchimage(iw,ih,j){
	iWidth=parseInt(eval("document.pic"+j+".width"));
	iHeight=parseInt(eval("document.pic"+j+".height"));
	if(iWidth>parseInt(iw) && iWidth>=iHeight){
		eval('document.pic'+j+'.height=parseInt(iw)/iWidth*iHeight;');
		eval('document.pic'+j+'.width=parseInt(iw);');
	}
	else if(iHeight>parseInt(ih) && iHeight>iWidth){
		eval('document.pic'+j+'.width=parseInt(ih)/iHeight*iWidth;');
		eval('document.pic'+j+'.height=parseInt(ih);');
	}

	eval('document.pic'+j+'.style.visibility="visible";');
}

function checkvalue() {
		if(document.inputform.name.value == ""){
			alert("ۼ ̸  ּ.");
			document.inputform.name.focus();
			return true;
		}
		else if(document.inputform.picture.value == ""){
			alert("ε ׸ ϼ.");
			document.inputform.picture.focus();
			return true;
		}
		else if(document.inputform.passwd.value == ""){
			alert("йȣ Է ּ.");
			document.inputform.passwd.focus();
			return true;
		}
		else if(document.inputform.ne.value == ""){
			alert("Խù ̳   Է ּ.");
			document.inputform.ne.focus();
			return true;
		}
		else{
			document.inputform.submit();
		}
}


function checksearch() {
		if
		(document.searchform.search_word.value == ""){
			alert("˻ Է ּ.");
			document.searchform.search_word.focus();
			return true;
		}
		else {
			document.searchform.submit();
		}
}

function Openwindow(name, url, left, top, width, height, toolbar, menubar, statusbar, scrollbar, resizable)
// script from Namo Webeditor
{
  toolbar_str = toolbar ? 'yes' : 'no';
  menubar_str = menubar ? 'yes' : 'no';
  statusbar_str = statusbar ? 'yes' : 'no';
  scrollbar_str = scrollbar ? 'yes' : 'no';
  resizable_str = resizable ? 'yes' : 'no';
  window.open(url, name, 'left='+left+',top='+top+',width='+width+',height='+height+',toolbar='+toolbar_str+',menubar='+menubar_str+',status='+statusbar_str+',scrollbars='+scrollbar_str+',resizable='+resizable_str);
}
</script>

<!-- ۾ κ  -->

<table align="center" cellpadding="0" cellspacing="0" width="640">
<tr><td width="974" height="20" background="skin/<?php echo $admin_data[skin]?>/title_bg.gif">
<table cellpadding="0" cellspacing="0" width="100%">
<tr><td width="17" height="25" background="skin/<?php echo $admin_data[skin]?>/title_bg.gif">
<p align="center">
<img src="skin/<?php echo $admin_data[skin]?>/write.gif" width="14" height="20" border="0" alt="write.gif">
</p></td><td width="674" height="20" background="skin/<?php echo $admin_data[skin]?>/title_bg.gif">
<p><font color="<?php echo $skin[sfont2_color]?>">&nbsp;<b> Խù ۼ..</b></font></p>
</td></tr>
</table>
</td></tr>

<tr><td>
<form name="inputform" method="post" action="./post_article.php" enctype="multipart/form-data" onsubmit="this.submit_btn.disabled=true">

<TABLE border=1 width=640 cellspacing=0 cellpadding=7 bgcolor="<?php echo $skin[image_table_bgcolor]?>"><TR ALIGN=CENTER><TD>
<table border=0 cellpadding=0 cellspacing=0><tr><td>
<TABLE BORDER=0 CELLPADDING=0 CELLSPACING=0>
<TR><TD WIDTH=50>Name</TD>
<TD><INPUT TYPE=text NAME="name" SIZE=20 MAXLENGTH=30 VALUE="<?php echo $HTTP_COOKIE_VARS["hboard10_name"]?>"></TD></TR>

<TR><TD>Mail</TD><TD>
<INPUT TYPE=text NAME="email" SIZE=32 MAXLENGTH=100 VALUE="<?php echo $HTTP_COOKIE_VARS["hboard10_email"]?>"></TD></TR>

<TR><TD>URL(*)</TD><TD>
<INPUT TYPE=text NAME="homepage" SIZE=32 MAXLENGTH=255 VALUE="
<?php
if($HTTP_COOKIE_VARS["hboard10_homepage"] == "") echo "http://";
else echo $HTTP_COOKIE_VARS["hboard10_homepage"];
?>">
</TD></TR>

<TR><TD>File</TD><TD>
<INPUT TYPE=file NAME="picture" SIZE=20 MAXLENGTH=255 onChange='Preview(this.form,1);'>
<span style="font-size:8pt;">
<?php
if($admin_data[fileup_max] != "0") {
 //  ε   : KB, MB  ȯؼ Ѹ

 if($admin_data[fileup_max] <= 1023999) $fileup_max = (int)($admin_data[fileup_max]/1024+0.5) ."KB";
 else $fileup_max = sprintf("%0.2f", $admin_data[fileup_max]/1024/1024) ."MB";
 echo "(" .$fileup_max ." <font color=\"red\">MAX</font>)";
}
else {
echo "<font color=\"red\">(Unlimited)</font>";
}
?>

</span>
</TD></TR>

<TR><TD>Password</TD><TD>
<INPUT TYPE=password NAME="passwd" SIZE=9 MAXLENGTH=30></TD></TR>

<TR><TD WIDTH=50>Title</TD><TD>
 <input type=text name="title" size=32 maxlength=255 value=""></TD></TR>
</TABLE>

<TABLE BORDER=0 CELLPADDING=0 CELLSPACING=0>
<TR><TD><TEXTAREA NAME="ne" ROWS=7 COLS=45></TEXTAREA></TD></TR>
</TABLE>

<TABLE BORDER=0 CELLPADDING=0 CELLSPACING=0 WIDTH="100%">
<TR><TD ALIGN=CENTER>
<INPUT name="submit_btn" type=button value="Submit" onclick="checkvalue();" accesskey=s>&nbsp;<INPUT name="reset_btn" TYPE=reset VALUE="Reset">
</TD></TR>
</TABLE>
</form>
</td></tr>
</table>

<TD WIDTH=320 HEIGHT=240>
<DIV id='d_pic1' style='width:320px;height:240px;overflow:hidden;' align='center'>
<IMG border='0' name='pic1' SRC='skin/<?php echo $admin_data[skin]?>/preview.jpg' WIDTH='320' HEIGHT='240' alt='Preview'>
</DIV>

</TD></tr>
</table>
</td></tr>
</table>
<!-- ۾ κ  -->
<center>
<br>
<table align="center" width="90%" cellpadding="0" cellspacing="0" bgcolor="<?php echo $skin[image_table_bgcolor]?>">
<tr><td width="37">
<p align="center"><span style="font-size:9pt;">
<img src="skin/<?php echo $admin_data[skin]?>/info.jpg" width="32" height="32" alt="Info"></span></p>
</td>
<td>
<p><span style="font-size:9pt;"> <?php echo ($fileidx - $deleted_fileidx)?> Խù ϵǾ ֽϴ. ( Խù <?php echo $deleted_fileidx?>)<br> <?php echo $page?>  / ü&nbsp;<?php echo $startpage?>&nbsp; ( <?php echo $admin_data[app]?> , ̹ DB: <?php echo $db_size?>)</span></p>
</td>

<td width="37">
<p><span style="font-size:9pt;"><a href="#search" title="˻"><img src="skin/<?php echo $admin_data[skin]?>/search.jpg" width="32" height="32" alt="˻" border="0"></a></span></p>
</td>

<?php
/**********  α  óκ **********/

 if($HTTP_COOKIE_VARS["hboard_admin_login"] == $admin_data[passwd]) {
?>

<td width="37">
<p><span style="font-size:9pt;"><a href="javascript:Openwindow('hb_config', 'config.php?from=<?php echo $page_this?>', 30, 30, 700, 610, 0, 0, 0, 1, 1)" title="Խ ȯ "><img src="skin/<?php echo $admin_data[skin]?>/config.jpg" width="32" height="32" alt="Խ ȯ " border="0"></a></span></p>
</td>
<td width="37">
<p><span style="font-size:9pt;"><a href="javascript:Openwindow('hb_iconman', 'iconman.php', 60, 60, 610, 400, 0, 0, 0, 1, 1)" title=" "><img src="skin/<?php echo $admin_data[skin]?>/addicon.jpg" width="32" height="32" alt=" " border="0"></a></span></p>
</td>
<td width="37">
<p><span style="font-size:9pt;"><a href="admin_logout.php?from=<?php echo $page_this?>" title=" α׾ƿ"><img src="skin/<?php echo $admin_data[skin]?>/logout.jpg" width="32" height="32" alt=" α׾ƿ" border="0"></a></span></p>
</td>

<?php
 }
 else {
?>

<td width="37">
<p><span style="font-size:9pt;"><a href="javascript:Openwindow('hb_login', 'admin.php?from=<?php echo $page_this?>', 50, 50, 360, 140, 0, 0, 0, 0, 0)" title=" α"><img src="skin/<?php echo $admin_data[skin]?>/login.jpg" width="32" height="32" alt=" α" border="0"></a></span></p>
</td>

<?php
 }
/**********  α  óκ  **********/
?>
</tr></table>
<br>
<!-- ºκ  -->
<?php

 if($fileidx<=0) {
  echo "<br><font size=5>Ͱ ϴ!</font><br><font size=3> Է Խù ۼϿ ֽʽÿ.</font><br><br><hr color=\"${skin[hr_color]}\" width=\"90%\"><br>\n";
  }
 else {
  // PrintArticle  : PrintArticle(,,true/false) .. -.-
	PrintArticle($headart, ($footart+1), true);
 }

echo " <b><font color=blue>" .$page ."</font></b>  <font color=green>/</font> ü <b><font color=red>" .$startpage ."</font></b> <br>";

if($page>1) {
echo "<a href=\"list.php?page=1\" title=\"ù \">|</a>&nbsp;<a href=\"list.php?page=" .($page-1) ."\" title=\" \"></a>&nbsp;&nbsp;";
}
else {
echo "<font color=\"${image_table_bgcolor}\"><a title=\"ù \">|</a>&nbsp;<a title=\" \"></a></font>&nbsp;&nbsp;";
} //   ù  ư

// ģ for κ 
for($pagecnt=($page-4);; $pagecnt++) {
 if($pagecnt<=0) { } //  ó̸ do nothing;
 else if($pagecnt>=$page) {
	 break; } //   
 else {
	 echo "<a href=\"list.php?page=" .$pagecnt ."\">[" .$pagecnt ."]</a>&nbsp;"; }
}

echo "[<b>" .$page ."</b>]&nbsp;";

for($pagecnt=($page+1);; $pagecnt++) {

 if($page<=4) { // ù ?
  if($pagecnt>$startpage) { break; } //   
  else if($pagecnt>=(($page+10)-$page)) { break; }
  else { echo "<a href=\"list.php?page=" .$pagecnt ."\">[" .$pagecnt ."]</a>&nbsp;"; }
 }

 else { // ƴ  Ѥ..
  if($pagecnt>$startpage) { break; } //   
  else if($pagecnt>=($page+5)) { break; } // +5  
  else { echo "<a href=\"list.php?page=" .$pagecnt ."\">[" .$pagecnt ."]</a>&nbsp;"; }
 }
}

// ģ for κ 

if(($footart+1)<=1) {
echo "&nbsp;<font color=\"${image_table_bgcolor}\"><a title=\" \"></a>&nbsp;<a title=\" \">|</a></font>";
}

else {
echo "&nbsp;<a href=\"list.php?page=" .($page+1) ."\" title=\" \"></a>&nbsp;<a href=\"list.php?page=" .$startpage ."\" title=\" \">|</a>";
} //     ư..Ѥ

?>
<span style="font-size:6pt;"><br><br></span>
<a name="search"></a>
<form name="searchform" action="search.php">
<table width="314" align="center" cellpadding="0" cellspacing="0" bgcolor="<?php echo $skin[image_table_bgcolor]?>">
    <tr>
        <td width="18" height="37">
                <p align="center">
		<span style="font-size:9pt;">&nbsp;</span></p>
        </td>
        <td width="56" height="37">
                <p align="center">
                <span style="font-size:9pt;"><img src="skin/<?php echo $admin_data[skin]?>/search.jpg" width="32" height="32" alt="˻" border="0"></span></p>
        </td>
        <td width="79" height="37">
                 <p align="center"><span style="font-size:9pt;">
				<select name="search_type" size="1">
                <option value="name">ۼ</option>
                <option value="subject"> </option>
                <option value="ment"> </option>
                <option value="cfile"> ̸</option>
                </select></span></p>
        </td>
        <td width="120" height="37">
            <p align="center"><span style="font-size:9pt;"><input type="text" name="search_word" maxlength="50" size="15"></span></p>
        </td>
        <td width="50" height="37">
            
                <p align="left">&nbsp;<span style="font-size:9pt;"><input type="button" name="search_go" value="˻" onclick="checksearch();"></span>
        </td>
        <td width="15" height="37">
                <p><span style="font-size:9pt;">&nbsp;</span></p>

        </td>
    </tr>
</table>
</form>

</center>

<!-- ºκ  -->

<?php
}
PrintFooter();
?>
